==> haskell-yaml-0.8.21.1-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.8.21.1
id: yaml-0.8.21.1-AVEYDGyJx5gG3MACMHmcea
key: yaml-0.8.21.1-AVEYDGyJx5gG3MACMHmcea
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/snoyberg/yaml/
synopsis: Support for parsing and rendering YAML documents.
description:
    Please see the README.md file.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
exposed: True
exposed-modules:
    Text.Libyaml Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder
    Data.Yaml.Config Data.Yaml.Include Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH
hidden-modules: Data.Yaml.Internal
abi: 92b816acf7350b0116c7c34e0f87b889
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yaml-0.8.21.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/yaml-0.8.21.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/yaml-0.8.21.1
hs-libraries: HSyaml-0.8.21.1-AVEYDGyJx5gG3MACMHmcea
depends:
    aeson-1.0.2.1-FRh8NWzqPiiuj2q5G5H5S
    attoparsec-0.13.1.0-IbZnQWsljer1cy7HS9Csat base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    containers-0.5.7.1 directory-1.2.6.2
    enclosed-exceptions-1.0.2-LMjQACvzJ8YmslYTB8HhY filepath-1.4.1.0
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    scientific-0.3.4.9-1EMxAMphVKV1cR2UEyLvhJ
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.8.22-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yaml
version: 0.8.22
id: yaml-0.8.22-INeHbn75CrTI4wcMhFaML4
key: yaml-0.8.22-INeHbn75CrTI4wcMhFaML4
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/snoyberg/yaml/
synopsis: Support for parsing and rendering YAML documents.
description:
    Please see the README.md file.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
exposed: True
exposed-modules:
    Text.Libyaml Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder
    Data.Yaml.Config Data.Yaml.Include Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH
hidden-modules: Data.Yaml.Internal
abi: b1885836649750b6662b8f70416fffd3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yaml-0.8.22
library-dirs: /usr/lib/ghc-8.0.1/site-local/yaml-0.8.22
data-dir: /usr/share/i386-linux-ghc-8.0.1/yaml-0.8.22
hs-libraries: HSyaml-0.8.22-INeHbn75CrTI4wcMhFaML4
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    containers-0.5.7.1 directory-1.2.6.2 filepath-1.4.1.0
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    scientific-0.3.4.10-HyHkymmV2uwD8dEKuPMVuU
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html: /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
